#include <string>
#include "unit_generic.h"
using std::string;

VSSprite * createVSSprite(const char *file)
{
	return NULL;
}

void cache_ani (string s) {}
void update_ani_cache () {}

std::string getRandomCachedAniString () {
    return "";
}
Animation* getRandomCachedAni () {
    return NULL;
}
